Fullerenes

## 2.1 Fullerenes

The options to define the input parameters for the construction of the fullerene are displayed in the Calculations–Input options:

Figure 2: `NanoCap` input options for a fullerene

Here you can set the options for:

- the number of dual lattice points or carbon atoms

- the seed for the initial random arrangement of dual lattice points

- the number of dual lattice points to hold fixed at either the poles or the equator

Upon on clicking Initialise the dual lattice points belonging to the fullerene will be constructed via the following:

|  |  | (1)

where and are two random numbers in the range [1,1] and [0,2]. To visualise these points, check the options outlined in Section 7. The process of optimisation of these points is described in Section 5